==> venus-client-2.2.5-sources.jar: com/meidusa/venus/client/xml/bean/Remote.java <==
/*
 * Copyright 2008-2108 amoeba.meidusa.com 
 * 
 * 	This program is free software; you can redistribute it and/or modify it under the terms of 
 * the GNU AFFERO GENERAL PUBLIC LICENSE as published by the Free Software Foundation; either version 3 of the License, 
 * or (at your option) any later version. 
 * 
 * 	This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
 * See the GNU AFFERO GENERAL PUBLIC LICENSE for more details. 
 * 	You should have received a copy of the GNU AFFERO GENERAL PUBLIC LICENSE along with this program; 
 * if not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package com.meidusa.venus.client.xml.bean;
import com.meidusa.venus.client.authenticate.Authenticator;

public class Remote {
	private String name;
	private FactoryConfig factory;
	private PoolConfig pool;
	private Authenticator authenticator;
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public FactoryConfig getFactory() {
		return factory;
	}
	public void setFactory(FactoryConfig factory) {
		this.factory = factory;
	}
	public PoolConfig getPool() {
		return pool;
	}
	public void setPool(PoolConfig pool) {
		this.pool = pool;
	}
	public Authenticator getAuthenticator() {
		return authenticator;
	}
	public void setAuthenticator(Authenticator authenticator) {
		this.authenticator = authenticator;
	}
	
}

==> venus-client-2.2.7-sources.jar: com/meidusa/venus/client/xml/bean/Remote.java <==
/*
 * Copyright 2008-2108 amoeba.meidusa.com 
 * 
 * 	This program is free software; you can redistribute it and/or modify it under the terms of 
 * the GNU AFFERO GENERAL PUBLIC LICENSE as published by the Free Software Foundation; either version 3 of the License, 
 * or (at your option) any later version. 
 * 
 * 	This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
 * See the GNU AFFERO GENERAL PUBLIC LICENSE for more details. 
 * 	You should have received a copy of the GNU AFFERO GENERAL PUBLIC LICENSE along with this program; 
 * if not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package com.meidusa.venus.client.xml.bean;
import com.meidusa.venus.client.authenticate.Authenticator;

public class Remote {
	private String name;
	private int loadbalance = 1;
	private FactoryConfig factory;
	private PoolConfig pool;
	private Authenticator authenticator;
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public FactoryConfig getFactory() {
		return factory;
	}
	public void setFactory(FactoryConfig factory) {
		this.factory = factory;
	}
	public PoolConfig getPool() {
		return pool;
	}
	public void setPool(PoolConfig pool) {
		this.pool = pool;
	}
	public Authenticator getAuthenticator() {
		return authenticator;
	}
	public void setAuthenticator(Authenticator authenticator) {
		this.authenticator = authenticator;
	}
	public int getLoadbalance() {
		return loadbalance;
	}
	public void setLoadbalance(int loadbalance) {
		this.loadbalance = loadbalance;
	}
	
}
